@@ -26,11 +26,11 @@ if ($^O eq 'MSWin32') {
 $parser->getopts("hi:r:svx");
 if ($parser->YYData->{opt_v}) {
 	use CORBA::XMLSchemas::xsd;
-	print "CORBA::XMLSchemas $CORBA::XMLSchemas::VERSION\n";
-	print "CORBA::IDL $CORBA::IDL::VERSION\n";
+	print "CORBA::XMLSchemas $CORBA::XMLSchemas::xsd::VERSION\n";
+	print "CORBA::IDL $CORBA::IDL::node::VERSION\n";
 	print "IDL $Parser::IDL_version\n";
 	print "$0\n";
-	print "Perl $]\n";
+	print "Perl $] on $^O\n";
 	exit;
 }
 if ($parser->YYData->{opt_h}) {
